# gnuplot 4.2 plot file
set multiplot

# main plot
reset
set encoding iso_8859_1

set rmargin at screen 0.998
set tmargin at screen 0.98
set lmargin at screen 0.1111
set bmargin at screen 0.40

set format x "%.0s%c"
set format y "10^{%T}"

set xlabel "Fourier frequency (Hz)"
set ylabel "relative power noise (Hz^{-1/2})"
set key right top
set logscale x
set logscale y
set yrange [:]
set xrange [1:10e3]

set grid
set mxtics 10
set mytics 10

set size 1, 0.8
set samples 500

set style line 30 lt rgb "#d3362b" lw 1
set style line 32 lt rgb "#2a4577" lw 2
set style line 34 lt rgb "#008a2e" lw 2
set style line 35 lt rgb "dark-magenta" lw 3

nan = sqrt(-1)
req_ctr(f) = (f<0.1) ? nan : (f<0.2) ? 1e-2 : (f<0.5) ? 1e-2*(f/0.2)**-6.78 : (f<10) ? 2e-5*(f/0.5)**-3.07 : nan
req_outer(f) = (f<10) ? req_ctr(f) : (f<2e3) ? 2e-9*(f/10.0) : (f<9e6) ? 4e-7 : nan
req_inner(f) = (f<25) ? nan : (f<100) ? 2e-8 : (f<2e3) ? 4e-7*(f/2e3) : 4e-7
iss_integrator(f) = (f<5e3) ? 1/f * 5e3 : 1
iss_loop_gain(f) = 1/f * 50e3 * iss_integrator(f)

set xtics 1,10,9e3
set xtics add ("10k      " 10e3)

plot \
  'plot_lsd.dat' title  'measurement'  w l ls 30,\
   req_inner(x) * iss_loop_gain(x) title 'laser requirements' w l ls 35


# subplot 1
reset

set rmargin at screen 0.64
set tmargin at screen 0.31
set lmargin at screen 0.1111
set bmargin at screen 0.06

set xlabel "time (s)"
set ylabel "signal (V)"
set grid front
set size 0.6, 0.5
set style fill solid 0.25 border

set palette model RGB  
set palette defined ( 0 "white", 1 "yellow", 2 "orange", 3 "red", 4 "#8B0000")
unset colorbox

set style line 30 lt rgb "#d3362b" lw 2
set style line 32 lt rgb "#2a4577" lw 1
set style line 33 lt rgb "#2a4577" lw 2
set style line 34 lt rgb "#008a2e" lw 2


plot [1:60] [9.25248737335:9.28731327057] \
  'plot_runhist.dat' using ($1/65536+1):2:3 notitle with image, \
  'plot_timesignal.dat' using ($1/65536+1):3 notitle w l ls 33, \
  '' using ($1/65536+1):2 notitle w l ls 32, \
  '' using ($1/65536+1):4 notitle w l ls 32

# subplot 2

reset

set rmargin at screen 0.998
set tmargin at screen 0.31
set lmargin at screen 0.7
set bmargin at screen 0.06

set xlabel "relative count"
set grid

set ytics ("min" 9.25746250153, "avg" 9.27001900598, "max" 9.2823381424)

set size 0.4, 0.5

set style line 30 lt rgb "#d3362b" lw 2
set style line 32 lt rgb "#2a4577" lw 2
set style line 34 lt rgb "#008a2e" lw 2

set yrange [9.25248737335:9.28731327057]

plot  \
  'plot_histogram.dat' using ($2/3932160.0):1 title 'dc' w steps ls 30, \
  '' using ($4/3932160.0):3 title 'ac' w steps ls 32


unset multiplot
